<?php

namespace Drupal\standwithukraine\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Class StandWithUkraineForm.
 *
 * @package Drupal\standwithukraine\Form
 */
class StandWithUkraineForm extends ConfigFormBase {

  /**
   * The suggested websites list.
   */
  const URLS = [
    'https://supportukrainenow.org',
    'https://war.ukraine.ua/',
  ];

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['standwithukraine.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'standwithukraine_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config($this->getEditableConfigNames()[0]);

    $form['url'] = [
      '#type' => 'url',
      '#title' => $this->t('Link'),
      '#description' => sprintf(
        '%s %s.',
        $this->t('For example:'),
        implode(
          ', ',
          array_map(
            function ($url) {
              return Link::fromTextAndUrl(
                parse_url($url, PHP_URL_HOST),
                Url::fromUri($url, ['target' => '_blank'])
              )->toString();
            },
            self::URLS
          )
        )
      ),
      '#default_value' => $config->get('url'),
    ];

    $form['position'] = [
      '#type' => 'radios',
      '#title' => $this->t('Position'),
      '#description' => $this->t('Select on which side of the page a message
should be displayed.'),
      '#options' => [
        'left' => $this->t('Left'),
        '' => $this->t('Top (default)'),
        'right' => $this->t('Right'),
      ],
      '#default_value' => $config->get('position') ?? '',
    ];

    $form['offset'] = [
      '#type' => 'number',
      '#title' => $this->t('Offset'),
      '#description' => $this->t('How many pixels down the message should be
shifted down the page. When a field is empty then the message will be shifted
down by 20 percent from the page height. Available only for the left or right
position of the message.'),
      '#min' => 0,
      '#field_suffix' => $this->t('pixels'),
      '#default_value' => $config->get('offset'),
      '#states' => [
        'enabled' => [
          ':input[name="position"]' => [
            ['value' => 'left'],
            ['value' => 'right'],
          ],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config($this->getEditableConfigNames()[0]);

    foreach (['url', 'position', 'offset'] as $key) {
      $config->set($key, $form_state->getValue($key));
    }

    $config->save();

    parent::submitForm($form, $form_state);
  }

}
